Bounded HTTP and torrent helpers shared by registry install and transport adapters.
Re-exports
pub use crate::resource_limits::MAX_HTTP_RESPONSE_BYTES;pub use crate::resource_limits::MAX_TORRENT_ARTIFACT_BYTES;
Structs
Functions
- download_
registry_ artifact - Download a registry artifact using torrent pieces when a sidecar exists, else bounded HTTP GET.
- http_
get - http_
get_ with_ headers - http_
post - http_
put - join_
url