Module fetch

Module fetch 

Bounded HTTP and torrent helpers shared by registry install and transport adapters.

Re-exports

pub use crate::resource_limits::MAX_HTTP_RESPONSE_BYTES;
pub use crate::resource_limits::MAX_TORRENT_ARTIFACT_BYTES;

Structs

HttpResponse

Functions

download_registry_artifact
Download a registry artifact using torrent pieces when a sidecar exists, else bounded HTTP GET.
http_get
http_get_with_headers
http_post
http_put
join_url